
#import <appkit/appkit.h>
#import "Understudy.h"
#import "DocumentInfo.h"
#import <sys/time.h>
#import <remote/NXProxy.h>

@interface UnderstudyAgent:Understudy
{
    id	iconImage ;
    id  oldIconImage ;
    id  MotionIntervalField ;
    id  StrollXField ;
    id  StrollYField ;
    id	XField;
    id	YField;
    id  XScroller;
    id  YScroller;
    int iX ;
    int iY ;
    char *szIconName[400] ;
    int iIconCount ;
    BOOL bIsVisible ;
    BOOL bTextDisplay ;
    BOOL bHasIcon ;
    BOOL bDropEnabled ;
    BOOL bShouldDisplayIcon ;
    BOOL bShouldLaunchFile ;
    BOOL bStrollingSuspended ;
    BOOL bFlippingSuspended ;
    NXPoint iconPosition ;
    double dStrollInterval ;

    /* distribution vars */
    char service[100] ;
    char host[100] ;
    BOOL bIsAdvertising ;
    id subscriberList ;
    id connectionList ;
    id connection ;
    BOOL bIsSubscribing ;
    BOOL bShouldKeepSeeking ;
    id server ;
    DPSTimedEntry pingEntry ;
}
/* subclassed methods */
- initFromGraphic:(const STR)szFile at:(NXPoint *)theLocation in:(id)theWindow ;
- drawSelf:(const NXRect *)rects :(int)rectCount ;
- mouseDown:(NXEvent *)theEvent ;
- strollTo:(NXCoord)x :(NXCoord)y interval:(double)dInterval 
	   steps:(int)iSteps ;
- strollBy:(NXCoord)x :(NXCoord)y interval:(double)dInterval ;
- strollBounce:(NXCoord)x :(NXCoord)y interval:(double)dInterval ; 
- stopStroll:sender ;

/* dropping methods */

- setDropEnabled:(BOOL)bFlag ;
- (BOOL)dropEnabled ;
- setShouldDisplayIcon:(BOOL)bFlag ;
- (BOOL)shouldDisplayIcon ;
- setShouldLaunchFile:(BOOL)bFlag ;
- (BOOL)shouldLaunchFile ;
- clearIcon ;
- (const char **)droppedFiles ;
- setAttachments:(const char **)theFiles ;
- (int)numAttachments ;
- (const char *)getAttachment:(int)num ;
- droppedIcon ;

/* Document Methods */
- saveTo:(P_SAVEINFO)theInfo ;
- loadFrom:(P_SAVEINFO)theInfo ;
- finishLoad ;

/* dragging methods */
- registerForDragging;
- (NXDragOperation)draggingEntered:(id <NXDraggingInfo>)sender;
- (NXDragOperation)draggingUpdated:(id <NXDraggingInfo>)sender;
- draggingExited:(id <NXDraggingInfo>)sender ;
- (BOOL)performDragOperation:(id <NXDraggingInfo>)sender;

/* Agent specific methods */

- setIconLocation:(NXPoint *)thePosition ;

/* methods implemented by the delegate */
- dropOccurred:sender ;
- clearOccurred:sender ;
- launchOccurred:sender ;
- specialActivationOccurred:sender ;

@end

/* pasteboard type declarations */
extern NXAtom OHI_UnderstudyPboardType ;
extern char *OHI_UnderstudyPasteboardType ;

@interface UnderstudyAgent(pasteboardMethods)
- copy:sender ;
- cut:sender ;
- delete:sender ;
- paste:sender ;
- setupPasteboard ;
@end

@interface UnderstudyAgent(PasteboardDelegateMethods)

- cutRequestMade:sender ;
- deleteRequestMade:sender ;
- pasteRequestMade:sender for:(SAVEINFO *)theInfo ;

@end

@interface UnderstudyAgent(InspectorMethods)

 /* Attributes Methods */
- (const char *)getUnderstudyPartName ;
- setUnderstudyPartName:(const char *)theName ;
- (BOOL)getUnderstudyVisibility ;
- toggleUnderstudyVisibility ;
- getUnderstudyDragEnable ;
- setUnderstudyDragEnable ;
 /* Animation Methods */

 /* Attatchments */
- getUnderstudyIconXField ;
- setUnderstudyIconXField ;
- getUnderstudyIconYField ;
- setUnderstudyIconYField ;
- getUnderstudyIconImage ;
- setUnderstudyIconImage ;
- (BOOL)getUnderstudyLaunchEnable ;
- setUnderstudyLaunchEnable ;
- (BOOL)getUnderstudyDropEnable ;
- setUnderstudyDropEnable ;
- (BOOL)getUnderstudyIconDisplayEnable ;
- setUnderstudyIconDisplayEnable ;
 /* Text */
- getUnderstudyTextDisplayEnable ;
- setUnderstudyTextDisplayEnable ;
- getUnderstudyTextSourcePartName ;
- setUnderstudyTextSourcePartName ;
- getUnderstudyTextSourceAttatchment ;
- setUnderstudyTextSourceAttatchment ;
- getUnderstudyTextSourceScript ;
- setUnderstudyTextSourceScript ;
- getUnderstudyTextSourceAssigned ;
- setUnderstudyTextSourceAssigned ;
- getUnderstudyTextColor ;
- setUnderstudyTextColor ;
- getUnderstudyAssignedText ;
- setUnderstudyAssignedText ;
 /* Actions */
- getUnderstudyActionTypeNone ;
- setUnderstudyActionTypeNone ;
- getUnderstudyActionTypeFromScript ;
- setUnderstudyActionTypeFromScript ;
- getUnderstudyActionTypeFromBrowser ;
- setUnderstudyActionTypeFromBrowser ;
 /* Miscellaneous */
- getUnderstudySound ;
- setUnderstudySound ;
- getUnderstudySoundPlayOff ;
- setUnderstudySoundPlayOff ;
- getUnderstudySoundPlayOnBounce ;
- setUnderstudySoundPlayOnBounce ;
- getUnderstudySoundPlayWhenSelected ;
- setUnderstudySoundPlayWhenSelected ;
- getUnderstudySoundPlayWhenVisible ;
- setUnderstudySoundPlayWhenVisible ;
- getUnderstudySoundPlayFromScript ;
- setUnderstudySoundPlayFromScript ;

@end

@interface UnderstudyAgent(DistributionMethods) <NXSenderIsInvalid>

- advertise:(const char *)description ;
- (const char *)advertisedService ;
- server ;
- (const char *)serviceSubscribedTo ;
- subscriberList ;
- subscribeTo:(const char *)description ;
- subscribeTo:(const char *)description onHost:(const char *)hostname ;
- subscribeTo:(const char *)description onHost:(const char *)hostname keepTrying:(BOOL)flag ;
- unadvertise ;
- unsubscribe ;

/* connection updating methods */
- attachmentsChanged ;
- ping ;
- updateSubscriberAttachments ;

/* connection communication methods */
- addSubscriber:aSubscriber ;
- removeSubscriber:aSubscriber ;
- serverIsDying ;

/* communication link management functions */
- startPeriodicPing ;
- stopPeriodicPing ;
- pingServer ;
- startPeriodicSeekServer ;
- stopPeriodicSeekServer ;
- seekServer ;

@end

